@@ -5,7 +5,7 @@ use utf8;
 use Furl::HTTP;
 use Furl::Response;
 use Carp ();
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use 5.008001;
 
@@ -39,11 +39,13 @@ sub request {
     } else {
         my $req = shift;
         %args = @_;
+        my $req_headers= $req->headers;
+        $req_headers->remove_header('Host'); # suppress duplicate Host header
         my $headers = +[
             map {
                 my $k = $_;
-                map { ( $k => $_ ) } $req->headers->header($_);
-            } $req->headers->header_field_names
+                map { ( $k => $_ ) } $req_headers->header($_);
+            } $req_headers->header_field_names
         ];
 
         $args{url}     = $req->uri;
